@@ -36,7 +36,7 @@ class ANALITZAPLOT_EXPORT PlotsDictionaryModel : public QStandardItemModel
 {
 Q_OBJECT
 public:
-    enum Roles { ExpressionRole = Qt::UserRole+1, TitleRole, FileRole };
+    enum Roles { ExpressionRole = Qt::UserRole+1, FileRole };
     PlotsDictionaryModel(QObject* parent = 0);
     ~PlotsDictionaryModel();
     
@@ -44,6 +44,7 @@ public:
     void setCurrentRow(int row);
     
     PlotsModel* plotModel();
+    void createDictionary(const QString& path);
     
 public slots:
     ///convenience class for currentRow
@@ -51,7 +52,6 @@ public slots:
     
 private:
     void updatePlotsModel();
-    void createDictionary(const QString& title, const QString& file);
     
     QPointer<PlotsModel> m_plots;
     int m_currentItem;
