@@ -30,6 +30,11 @@
 #include <QMatrix4x4>
 
 #define GL_GLEXT_PROTOTYPES
+#ifdef Q_OS_WIN
+#include <windows.h>
+#include <GL/glew.h>
+#endif
+
 #include <GL/glu.h>
 
 class QAbstractItemModel;
